import React, { useState } from 'react';
import { StyledAccordion, StyledItemBody, StyledHeader, StyledItem, StyledButton, StyledControllerWrapper, } from './styles';
import Heading from '../Heading';
const AccordionItem = ({ children, titleSize = 'M', toggleItem, itemIndex = -1, itemIndexList = [], summary, title, className, style, }) => {
    return (React.createElement(StyledItem, { isActive: itemIndexList.includes(itemIndex), className: className, style: style },
        React.createElement(StyledHeader, { onClick: () => toggleItem && toggleItem(itemIndex) },
            React.createElement(Heading, { as: "h2", size: titleSize },
                React.createElement(StyledButton, null, title)),
            React.createElement("span", null),
            summary),
        children));
};
const Accordion = ({ children, showController = true, className, style, }) => {
    const [itemIndexList, setItemIndexList] = useState([]);
    const toggleItem = (itemIndex) => {
        itemIndexList.includes(itemIndex)
            ? setItemIndexList(itemIndexList.filter((item) => item !== itemIndex))
            : setItemIndexList([...itemIndexList, itemIndex]);
    };
    const toggleAllItems = () => {
        itemIndexList.length === children.length
            ? setItemIndexList([])
            : setItemIndexList(Array.from(Array(children.length).keys()));
    };
    const childrenCloned = React.Children.map(children, (child, i) => {
        if (React.isValidElement(child)) {
            return React.cloneElement(child, {
                itemIndexList,
                itemIndex: i,
                toggleItem,
            });
        }
        return child;
    });
    return (React.createElement(StyledAccordion, { className: className, style: style },
        showController && (React.createElement(StyledControllerWrapper, null,
            React.createElement(StyledButton, { onClick: () => toggleAllItems() },
                itemIndexList.length === children.length ? 'Zbaliť' : 'Rozbaliť',
                ' viac'))),
        childrenCloned));
};
Accordion.Item = AccordionItem;
Accordion.ItemBody = StyledItemBody;
StyledHeader.displayName = 'StyledHeader';
AccordionItem.displayName = 'Accordion.Item';
StyledItemBody.displayName = 'Accordion.ItemBody';
Accordion.displayName = 'Accordion';
export default Accordion;
