import styled, { css } from 'styled-components';
import { FONT_SIZE, MEDIA_QUERIES, SPACING } from '../../constants';
import { BLACK, GREY_2, LINK_COLOR, LINK_HOVER_COLOR, YELLOW, } from '../../global/colors';
export const StyledHeader = styled.div `
  position: relative;
  padding-right: 40px;
  padding-top: ${SPACING.SCALE_3};
  padding-bottom: ${SPACING.SCALE_3};
  border-top: 1px solid ${GREY_2};
  cursor: pointer;

  p {
    color: ${BLACK};
    margin: 0;
    margin-top: 10px;
  }

  & button {
    margin-top: 0;
    color: ${LINK_COLOR};
    text-decoration: none;

    :after {
      content: '';
      position: absolute;
      top: 0;
      right: 0;
      bottom: 0;
      left: 0;
    }
  }

  & > span {
    position: absolute;
    top: 50%;
    right: ${SPACING.SCALE_3};
    width: 16px;
    height: 16px;
    margin-top: -8px;

    :before {
      content: '';
      box-sizing: border-box;
      position: absolute;
      top: 0;
      right: 0;
      bottom: 0;
      left: 0;
      width: 100%;
      height: 25%;
      margin: auto;
      border: 2px solid transparent;
      background-color: ${BLACK};
    }

    :after {
      content: '';
      box-sizing: border-box;
      position: absolute;
      top: 0;
      right: 0;
      bottom: 0;
      left: 0;
      width: 25%;
      height: 100%;
      margin: auto;
      border: 2px solid transparent;
      background-color: ${BLACK};
    }
  }
`;
export const StyledButton = styled.button `
  background-color: transparent;
  border: none;
  color: ${BLACK};
  display: inline-block;
  font-family: inherit;
  font-size: inherit;
  font-weight: inherit;
  line-height: inherit;
  cursor: pointer;
  padding: 0;
  outline: none;
  text-decoration: underline;
  text-decoration-thickness: max(1px, 0.0625rem);
  text-underline-offset: 0.1em;

  &:hover {
    color: ${LINK_COLOR};
    text-decoration: underline;
    text-decoration-thickness: max(3px, 0.1857rem, 0.12em);
    text-decoration-skip-ink: none;
  }

  &:focus {
    color: ${BLACK};
    background-color: ${YELLOW};
    box-shadow: 0 -2px ${YELLOW}, 0 4px ${BLACK};
    text-decoration: none;
    outline: 3px solid transparent;
  }
`;
export const StyledItemBody = styled.div `
  display: none;
  margin: 0;
  padding-top: ${SPACING.SCALE_3};
  padding-bottom: ${SPACING.SCALE_3};

  a {
    color: ${LINK_COLOR};
    font-size: ${FONT_SIZE.SIZE_16};
    display: block;
    width: fit-content;
    margin-bottom: ${SPACING.SCALE_1};

    ${MEDIA_QUERIES.TABLET} {
      font-size: ${FONT_SIZE.SIZE_19};
    }

    :visited {
      color: ${LINK_COLOR};
    }

    :hover {
      color: ${LINK_HOVER_COLOR};
      text-decoration: underline;
    }

    :focus {
      color: ${BLACK};
      background-color: ${YELLOW};
      box-shadow: 0 -2px ${YELLOW}, 0 4px ${BLACK};
      text-decoration: none;
      outline: 3px solid transparent;
    }
  }
`;
export const StyledAccordion = styled.div `
  border-bottom: 1px solid ${GREY_2};
`;
export const StyledControllerWrapper = styled.div `
  text-align: right;
  margin-bottom: 3px;

  button {
    :hover {
      color: ${BLACK};
    }
  }
`;
export const StyledItem = styled.div `
  & > div:nth-of-type(1) > div {
    margin-top: 10px;
    margin-bottom: 0;
  }

  & > div:nth-of-type(2) {
    display: none;

    & > div {
      margin-top: 5px;
      margin-bottom: 0;
    }
  }

  ${({ isActive }) => isActive &&
    css `
      & > div:nth-of-type(2) {
        display: block;
      }

      span {
        :after {
          height: 25%;
        }
      }
    `}

  h2 {
    margin-bottom: 0;
  }
`;
