import styled, { css } from 'styled-components';
import { MEDIA_QUERIES, FONT_SIZE } from '../../constants';
import { BLACK, DARK_BLUE, GREY_3, LINK_COLOR, LINK_HOVER_COLOR, YELLOW, } from '../../global/colors';
import SectionBreak from '../SectionBreak';
export const StyledSectionBreak = styled(SectionBreak) `
  ${({ separator }) => separator === 'top' &&
    css `
      background-color: ${DARK_BLUE};
      border: none;
      height: 2px;
      margin: 8px 0;
    `}

  ${({ separator }) => separator === 'bottom' &&
    css `
      background-color: ${GREY_3};
      border: none;
      height: 2px;
    `}
`;
export const StyledIframe = styled.iframe `
  border: 1px solid ${BLACK};
  height: 148px;
  margin-bottom: 30px;
  margin-top: 25px;
  width: 100%;
`;
export const StyledDescriptionContainer = styled.div `
  width: 100%;
`;
export const StyledContentWrapper = styled.div `
  display: flex;
  flex-direction: column;
`;
export const StyledLinkWrapper = styled.p `
  margin-top: 0;
  margin-left: 15px;
  margin-bottom: 20px;
  font-size: ${FONT_SIZE.SIZE_16};
  line-height: 1.25;

  ${MEDIA_QUERIES.TABLET} {
    font-size: ${FONT_SIZE.SIZE_19};
    line-height: 1.31579;
  }
`;
export const StyledAddress = styled.div `
  font-size: ${FONT_SIZE.SIZE_14};
  width: 100%;
  padding: 0;
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;

  ${MEDIA_QUERIES.TABLET} {
    width: 33.3333%;
    font-size: ${FONT_SIZE.SIZE_16};
  }

  ${({ variant }) => variant === 'full-width' &&
    css `
      ${StyledIframe} {
        height: 202px;
        margin-top: 0;
      }

      ${MEDIA_QUERIES.TABLET} {
        width: 100%;
        ${StyledContentWrapper} {
          flex-direction: row;
        }

        ${StyledDescriptionContainer} {
          width: 50%;
        }

        ${StyledIframe} {
          width: 50%;
          height: 202px;
          margin-top: 0;
        }
      }
    `}

  a {
    display: inline-block;
    font-size: 16px;
    line-height: 1.25;
    margin-top: 15px;
    color: ${LINK_COLOR};
    text-decoration: underline;
    text-decoration-thickness: max(1px, 0.0625rem);
    text-underline-offset: 0.1em;

    ${MEDIA_QUERIES.TABLET} {
      font-size: 19px;
      line-height: 1.31579;
    }

    :hover {
      color: ${LINK_HOVER_COLOR};
      text-decoration-thickness: max(3px, 0.1857rem, 0.12em);
      text-decoration-skip-ink: none;
    }

    :focus {
      color: ${BLACK};
      text-decoration: none;
      box-shadow: 0 -2px ${YELLOW}, 0 4px ${BLACK};
      background-color: ${YELLOW};
      outline: 3px solid transparent;
    }

    ::before {
      content: '';
      position: absolute;
      margin-top: 2px;
      margin-left: -15px;
      display: inline-block;
      width: 0;
      height: 0;
      border-style: solid;
      border-color: transparent;
      border-left-color: inherit;
      border-width: 6.5px 0 6.5px 11.285px;
      clip-path: polygon(0% 0%, 100% 50%, 0% 100%);
      background-color: inherit;

      ${MEDIA_QUERIES.TABLET} {
        margin-top: 4px;
      }
    }
  }

  h2 {
    margin-top: 0;
    margin-bottom: 10px;
  }
`;
