// @ts-nocheck
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
import styled from 'styled-components';
import * as React from 'react';
import { BORDER_WIDTH_FORM_ELEMENT, FOCUSABLE, MEDIA_QUERIES, SPACING_POINTS } from '../../constants';
import { typography, spacing } from '../../global';
import { BUTTON_COLOR, BUTTON_COLOR_DARKEN_15, WHITE } from '../../global/colors';
import { darken, stripUnit } from 'polished';
const BUTTON_SHADOW_SIZE = BORDER_WIDTH_FORM_ELEMENT;
const RAW_SPACING_2 = SPACING_POINTS[2];
const RAW_BORDER_WIDTH = Number(stripUnit(BORDER_WIDTH_FORM_ELEMENT));
const RAW_SHADOW = Number(stripUnit(BUTTON_SHADOW_SIZE));
const HALF_SHADOW = RAW_SHADOW / 2;
const BASE_PAD = RAW_SPACING_2 - RAW_BORDER_WIDTH;
const StyledButton = styled('button').withConfig({
    shouldForwardProp: (prop) => !['isStart', 'buttonColor', 'buttonHoverColor', 'buttonShadowColor', 'buttonTextColor', 'icon'].includes(String(prop)),
})(({ isStart }) => typography.font({
    size: isStart ? '24' : '19',
    lineHeight: isStart ? '1' : '19px',
    weight: isStart ? 'bold' : undefined,
}), FOCUSABLE, ({ buttonColor = BUTTON_COLOR, buttonHoverColor = darken(0.05, buttonColor), buttonShadowColor = buttonColor === BUTTON_COLOR ? BUTTON_COLOR_DARKEN_15 : darken(0.15, buttonColor), buttonTextColor = WHITE, isStart, }) => ({
    boxSizing: 'border-box',
    display: 'inline-block',
    position: 'relative',
    width: '100%',
    marginTop: 0,
    padding: isStart // differs from govuk-frontend owing to how icons displayed
        ? `${BASE_PAD}px ${SPACING_POINTS[3]}px`
        : `${BASE_PAD - HALF_SHADOW}px ${SPACING_POINTS[2]}px`,
    border: `${BORDER_WIDTH_FORM_ELEMENT} solid transparent`,
    borderRadius: 0,
    color: buttonTextColor,
    backgroundColor: buttonColor,
    boxShadow: `0 ${BUTTON_SHADOW_SIZE} 0 ${buttonShadowColor}`,
    textAlign: 'center',
    verticalAlign: 'top',
    cursor: 'pointer',
    WebkitAppearance: 'none',
    [MEDIA_QUERIES.TABLET]: {
        width: 'auto',
    },
    '&:link, &:visited, &:active, &:hover': {
        color: buttonTextColor,
        textDecoration: 'none',
    },
    '&::-moz-focus-inner': {
        padding: 0,
        border: 0,
    },
    '&:hover, &:focus': {
        backgroundColor: buttonHoverColor,
    },
    ':active': {
        top: BUTTON_SHADOW_SIZE,
        boxShadow: 'none',
    },
    '::before': {
        content: '""',
        display: 'block',
        position: 'absolute',
        top: `-${BORDER_WIDTH_FORM_ELEMENT}`,
        right: `-${BORDER_WIDTH_FORM_ELEMENT}`,
        bottom: `-${RAW_BORDER_WIDTH + RAW_SHADOW}px`,
        left: `-${BORDER_WIDTH_FORM_ELEMENT}`,
        background: 'transparent',
    },
    '&:active::before': {
        top: `-${RAW_BORDER_WIDTH + RAW_SHADOW}px`,
    },
    ':disabled': {
        opacity: 0.5,
        background: buttonColor,
        ':hover': {
            backgroundColor: buttonColor,
            cursor: 'default',
        },
        ':focus': {
            outline: 'none',
        },
        ':active': {
            top: 0,
            boxShadow: `0 ${BUTTON_SHADOW_SIZE} 0 ${buttonShadowColor}`,
        },
    },
    ' svg': {
        maxWidth: '15px',
        [MEDIA_QUERIES.TABLET]: {
            marginLeft: SPACING_POINTS[2],
        },
    },
}), ({ icon }) => {
    if (icon) {
        return {
            display: 'flex',
            alignItems: 'center',
            justifyContent: 'space-between',
        };
    }
    return undefined;
}, spacing.withWhiteSpace({
    margin: { direction: 'bottom', size: 6, adjustment: RAW_SHADOW },
}));
const ButtonContents = styled('span')({
    flexGrow: 1,
});
export const Button = React.forwardRef((_a, ref) => {
    var { start, children, icon } = _a, props = __rest(_a, ["start", "children", "icon"]);
    return (React.createElement(StyledButton, Object.assign({ ref: ref, isStart: start, icon: icon }, props),
        icon ? React.createElement(ButtonContents, null, children) : children,
        icon));
});
Button.defaultProps = {
    icon: undefined,
    start: false,
    buttonColor: undefined,
    buttonHoverColor: undefined,
    buttonShadowColor: undefined,
    buttonTextColor: undefined,
};
Button.displayName = 'Button';
export default Button;
