//@ts-nocheck
/**
 * ### References
 *
 * - https://github.com/alphagov/govuk-frontend/blob/main/src/govuk/core/_typography.scss
 * - https://design-system.service.gov.uk/styles/typography/#headings
 */
import styled from 'styled-components';
import { SECONDARY_TEXT_COLOR } from '../../global/colors';
import { spacing, typography } from '../../global';
import { CAPTION_SIZES, MEDIA_QUERIES, SPACING_POINTS } from '../../constants';
/**
 * Sometimes you may need to make it clear that a page is part of a larger section or group. To do this, you can use a heading with a caption above it.
 *
 * - https://govuk-react.github.io/govuk-react/?path=/docs/caption
 * - https://design-system.service.gov.uk/styles/typography/#headings
 */
export const Caption = styled('span')(({ size }) => {
    const actualSize = Number.isNaN(Number(size)) ? CAPTION_SIZES[size] : size;
    if (!actualSize) {
        throw Error(`Unknown size ${size} used for header.`);
    }
    return typography.font({ size: actualSize });
}, ({ size }) => {
    const actualSize = Number.isNaN(Number(size)) ? CAPTION_SIZES[size] : size;
    // bottom margin - hard-coded values because they're a bit odd
    const marginStyle = actualSize > 19 ? { marginBottom: SPACING_POINTS[1] } : undefined;
    const marginResponsiveStyle = actualSize === 24 ? { [MEDIA_QUERIES.TABLET]: { marginBottom: 0 } } : undefined;
    return Object.assign(Object.assign({}, marginStyle), marginResponsiveStyle);
}, {
    display: 'block',
    color: SECONDARY_TEXT_COLOR,
}, spacing.withWhiteSpace());
Caption.defaultProps = {
    size: 'XL',
};
Caption.displayName = 'Caption';
export default Caption;
