// @ts-nocheck
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
import * as React from 'react';
import styled from 'styled-components';
import HintText from '../HintText';
import { FOCUS_COLOR } from '../../global/colors';
import { BORDER_WIDTH, BORDER_WIDTH_FORM_ELEMENT, FOCUS_WIDTH, SPACING_POINTS } from '../../constants';
import { spacing, typography } from '../../global';
const checkboxSize = SPACING_POINTS[7];
const labelPaddingLeftRight = SPACING_POINTS[3];
const StyledCheckbox = styled('label')(typography.font({ size: 19 }), {
    display: 'block',
    position: 'relative',
    minHeight: checkboxSize,
    padding: `0 0 0 ${checkboxSize}px`,
    clear: 'left',
}, spacing.withWhiteSpace({ marginBottom: 2 }));
const StyledInput = styled('input')({
    position: 'absolute',
    zIndex: 1,
    top: 0,
    left: 0,
    width: checkboxSize,
    height: checkboxSize,
    opacity: 0,
    ':checked + span:after': {
        opacity: 1,
    },
    ':focus + span:before': {
        outline: `${FOCUS_WIDTH} solid transparent`,
        outlineOffset: FOCUS_WIDTH,
        boxShadow: `0 0 0 ${FOCUS_WIDTH} ${FOCUS_COLOR}`,
    },
}, ({ disabled }) => ({
    cursor: disabled ? 'default' : 'pointer',
    ' + span': {
        opacity: disabled ? '.5' : '1',
        pointerEvents: disabled ? 'none' : 'auto',
    },
}));
const StyledLabel = styled('span')({
    display: 'inline-block',
    cursor: 'pointer',
    padding: `8px ${labelPaddingLeftRight}px ${SPACING_POINTS[1]}px`,
    MsTouchAction: 'manipulation',
    touchAction: 'manipulation',
    '::before': {
        content: "''",
        boxSizing: 'border-box',
        position: 'absolute',
        top: 0,
        left: 0,
        width: checkboxSize,
        height: checkboxSize,
        border: `${BORDER_WIDTH_FORM_ELEMENT} solid black`,
        background: 'transparent',
    },
    '::after': {
        content: "''",
        position: 'absolute',
        top: '11px',
        left: '9px',
        width: '18px',
        height: '7px',
        transform: 'rotate(-45deg)',
        border: 'solid',
        borderWidth: `0 0 ${BORDER_WIDTH} ${BORDER_WIDTH}`,
        borderTopColor: 'transparent',
        background: 'transparent',
        opacity: 0,
    },
});
const StyledCheckboxHint = styled(HintText)({
    display: 'block',
    paddingLeft: labelPaddingLeftRight,
    paddingRight: labelPaddingLeftRight,
});
const Checkbox = React.forwardRef((_a, ref) => {
    var { children, className, hint } = _a, props = __rest(_a, ["children", "className", "hint"]);
    return (React.createElement(StyledCheckbox, { className: className },
        React.createElement(StyledInput, Object.assign({ type: "checkbox" }, props, { ref: ref })),
        React.createElement(StyledLabel, null, children),
        hint && React.createElement(StyledCheckboxHint, null, hint)));
});
Checkbox.displayName = 'Checkbox';
Checkbox.defaultProps = {
    hint: undefined,
    className: undefined,
};
export default Checkbox;
