import styled, { css } from 'styled-components';
import { MEDIA_QUERIES, FONT_SIZE, FONT_WEIGHTS } from '../../constants';
import { YELLOW, LINK_COLOR, LINK_HOVER_COLOR, BLACK, BLUE, GREY_1, WHITE, } from '../../global/colors';
import Paragraph from '../Paragraph';
export const StyledWrapper = styled.div `
  width: 100%;
  float: left;
  box-sizing: border-box;
  display: block;
`;
export const StyledContainer = styled.div `
  display: block;

  & > a {
    font-size: ${FONT_SIZE.SIZE_16};
    font-weight: ${FONT_WEIGHTS.bold};
    line-height: 1.25;
    display: inline-block;
    margin-top: 15px;
    color: ${LINK_COLOR};
    text-decoration: underline;
    text-underline-offset: 0.1em;

    ${MEDIA_QUERIES.TABLET} {
      font-size: ${FONT_SIZE.SIZE_19};
      line-height: 1.31579;
    }

    :hover {
      color: ${LINK_HOVER_COLOR};
      text-decoration-thickness: max(3px, 0.1857rem, 0.12em);
      text-decoration-skip-ink: none;
    }

    :focus {
      color: ${BLACK};
      text-decoration: none;
      box-shadow: 0 -2px ${YELLOW}, 0 4px ${BLACK};
      background-color: ${YELLOW};
      outline: 3px solid transparent;
    }
  }

  & > hr {
    margin: 5px 0 10px 0;
  }
`;
export const StyledParagraph = styled(Paragraph) `
  color: ${GREY_1};
  font-size: ${FONT_SIZE.SIZE_14};
  font-weight: ${FONT_WEIGHTS.regular};
  line-height: 1.14286;
  padding-bottom: 15px;
  padding-top: 10px;
  margin: 0;

  ${MEDIA_QUERIES.TABLET} {
    padding-bottom: 20px;
    font-size: ${FONT_SIZE.SIZE_16};
    line-height: 1.25;
  }
`;
export const StyledCrossroad = styled.div `
  width: 100%;
  box-sizing: border-box;

  ${StyledWrapper} {
    ${({ hiding }) => hiding &&
    css `
        & > div:nth-child(n + 6) {
          display: none;
        }

        &:nth-child(2) {
          display: none;
        }
      `}

    ${MEDIA_QUERIES.TABLET} {
      &:nth-child(2) {
        display: block;
      }
    }
  }

  ${MEDIA_QUERIES.TABLET} {
    ${({ variant }) => variant === 'two-col' &&
    css `
        ${StyledWrapper} {
          width: 50%;
          float: left;

          &:first-child {
            padding-right: 15px;
          }
          &:nth-child(2) {
            padding-left: 15px;
          }
        }
      `}
  }

  ::after {
    content: '';
    display: table;
    clear: both;
  }
`;
export const StyledShowBtnWrapper = styled.div `
  width: 100%;
  padding: 15px 15px;
  text-align: center;
  position: relative;
  box-shadow: none;
  float: left;
  display: block;
  box-sizing: border-box;

  ${({ hiding }) => hiding &&
    css `
      box-shadow: 5px -35px 30px 40px ${WHITE};

      ${MEDIA_QUERIES.TABLET} {
        box-shadow: 5px -10px 70px 40px ${WHITE};
      }
    `}

  ${MEDIA_QUERIES.TABLET} {
    padding: 0 15px 10px 15px;
  }
`;
export const StyledShowBtn = styled.button `
  font-weight: ${FONT_WEIGHTS.regular};
  font-size: ${FONT_SIZE.SIZE_16};
  line-height: 1.25;
  background: none;
  border: none;
  text-align: center;
  text-decoration: underline;
  color: ${BLUE};
  width: auto;
  height: 100%;
  cursor: pointer;
  display: inline-block;

  ::before,
  ::after {
    border-style: solid;
    border-width: 0.1rem 0.1em 0 0;
    color: inherit;
    content: '';
    display: inline-block;
    height: 0.45em;
    right: 25px;
    top: 15px;
    transform: rotate(135deg);
    transition: all 0.2s ease-out;
    vertical-align: top;
    width: 0.45em;
  }

  ::before {
    margin: 4px 22px 0 0;
  }

  ::after {
    margin: 4px 0 0 20px;
  }

  ${MEDIA_QUERIES.TABLET} {
    ::before {
      margin: 5px 22px 0 0;
    }

    ::after {
      margin: 5px 0 0 20px;
    }
  }

  ${({ hiding }) => !hiding &&
    css `
      ::before,
      ::after {
        transform: rotate(-45deg);
        right: 50px;
        top: 20px;
        margin: 9px 12px 0 12px;
      }

      ${MEDIA_QUERIES.TABLET} {
        margin: 11px 12px 0 12px;
      }
    `};

  :active,
  :focus {
    outline: 3px solid transparent;
    color: ${BLACK};
    background-color: ${YELLOW};
    box-shadow: 0 -2px ${YELLOW}, 0 4px ${BLACK};
    text-decoration: none;
    width: auto;
    padding: 0 12px;
  }

  ${MEDIA_QUERIES.TABLET} {
    font-size: ${FONT_SIZE.SIZE_19};
    line-height: 1.31579;
  }
`;
