// @ts-nocheck
import * as React from 'react';
import styled from 'styled-components';
import BaseInput from '../Input/Input';
import LabelText from '../LabelText';
import Label from '../Label';
import multiInputInput from 'multi-input-input';
const StyledLabel = styled(Label)({
    marginRight: '20px',
    marginBottom: 0,
}, ({ year }) => ({
    width: year ? '70px' : '50px',
}));
const StyledList = styled('div')({
    display: 'flex',
});
class Input extends React.Component {
    constructor() {
        super(...arguments);
        this.inputs = {};
    }
    renderInput(label, name, key, defaultValue, error) {
        const { value, onChange, onBlur, onFocus, refs } = this.props;
        return (React.createElement(StyledLabel, { year: key === 'year' },
            React.createElement(LabelText, null, label),
            React.createElement(BaseInput, { name: name, error: !!error, defaultValue: defaultValue, value: value ? value[key] : undefined, onChange: (e) => onChange(e, key), onBlur: (e) => onBlur(e, key), onFocus: (e) => onFocus(e, key), ref: (input) => {
                    this.inputs[key] = input;
                    refs(this.inputs);
                } })));
    }
    render() {
        const { labels, names, defaultValues, error } = this.props;
        return (React.createElement(StyledList, null,
            this.renderInput(labels.day, names.day, 'day', defaultValues.day, error),
            this.renderInput(labels.month, names.month, 'month', defaultValues.month, error),
            this.renderInput(labels.year, names.year, 'year', defaultValues.year, error)));
    }
}
Input.defaultProps = {
    value: undefined,
    names: {
        day: 'DateFieldDay',
        month: 'DateFieldMonth',
        year: 'DateFieldYear',
    },
    defaultValues: {
        day: undefined,
        month: undefined,
        year: undefined,
    },
    labels: {
        day: 'Day',
        month: 'Month',
        year: 'Year',
    },
    error: false,
};
// This component is dependent on multiInputInput HOC so we always export with HOC
export default multiInputInput(Input);
