// @ts-nocheck
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
/**
 * ### References
 *
 * - https://github.com/alphagov/govuk-frontend/blob/main/src/govuk/components/details/_details.scss
 */
import * as React from 'react';
import styled from 'styled-components';
import { shape, spacing, typography } from '../../global';
import { stripUnit } from 'polished';
import { BLACK, FOCUS_COLOR, LINK_HOVER_COLOR, BORDER_COLOR } from '../../global/colors';
import { BORDER_WIDTH, FOCUS_WIDTH, SPACING_POINTS } from '../../constants';
const CUSTOM_FOCUS_WIDTH = `${Number(stripUnit(FOCUS_WIDTH)) + 1}px`;
const StyledDetails = styled('details')(typography.font({ size: 19 }), typography.textColor, spacing.withWhiteSpace({ marginBottom: 6 }), {
    display: 'block',
});
const StyledSummary = styled('summary')({
    display: 'inline-block',
    position: 'relative',
    marginBottom: SPACING_POINTS[1],
    paddingLeft: Number(stripUnit(SPACING_POINTS[4])) + Number(stripUnit(BORDER_WIDTH)),
    color: FOCUS_COLOR,
    cursor: 'pointer',
    ':hover': {
        color: LINK_HOVER_COLOR,
    },
    ':focus': {
        outline: `${CUSTOM_FOCUS_WIDTH} solid ${FOCUS_COLOR}`,
        outlineOffset: -1,
        color: BLACK,
        background: FOCUS_COLOR,
    },
    '::-webkit-details-marker': {
        display: 'none',
    },
    ':before': Object.assign(Object.assign({ content: '""', position: 'absolute', top: 0, bottom: 0, left: 0, margin: 'auto' }, shape.arrow({ direction: 'right', base: 14 })), { '[open] > &': shape.arrow({ direction: 'down', base: 14 }) }),
});
const SummaryText = styled('span')({
    textDecoration: 'underline',
});
const DetailsText = styled('div')({
    padding: SPACING_POINTS[3],
    paddingLeft: SPACING_POINTS[4],
    borderLeft: `${BORDER_WIDTH} solid ${BORDER_COLOR}`,
    p: {
        marginTop: 0,
        marginBottom: SPACING_POINTS[4],
    },
    '> :last-child, p:last-child': {
        marginBottom: 0,
    },
});
/**
 * Make a page easier to scan by letting users reveal more detailed information only if they need it.
 *
 * - https://govuk-react.github.io/govuk-react/?path=/docs/details
 * - https://design-system.service.gov.uk/components/details/
 */
export const Details = (_a) => {
    var { summary, children } = _a, props = __rest(_a, ["summary", "children"]);
    return (React.createElement(StyledDetails, Object.assign({}, props),
        React.createElement(StyledSummary, null,
            React.createElement(SummaryText, null, summary)),
        React.createElement(DetailsText, null, children)));
};
Details.defaultProps = {
    children: undefined,
    open: false,
};
Details.displayName = 'Details';
export default Details;
