//@ts-nocheck
/**
 * ### References:
 *
 * - https://components.publishing.service.gov.uk/component-guide/document_list
 * - https://github.com/alphagov/static/blob/077649737c43d3937f745df0b3adade9df3717dc/app/views/govuk_component/docs/metadata.yml
 * - https://github.com/alphagov/static/blob/077649737c43d3937f745df0b3adade9df3717dc/app/views/govuk_component/metadata.raw.html.erb
 */
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
import * as React from 'react';
import styled from 'styled-components';
import UnorderedList from '../UnorderedList';
import { NTA_LIGHT } from '../../constants';
import { spacing } from '../../global';
const StyledContainer = styled('div')({ fontFamily: NTA_LIGHT }, spacing.withWhiteSpace());
const StyledDefinition = styled('li')({
    fontSize: '24px',
    fontWeight: 700,
    lineHeight: 1.25,
    '> a': {
        textDecoration: 'none',
    },
});
/**
 * An ordered list of documents including a document type, when updated and a link.
 *
 * - https://govuk-react.github.io/govuk-react/?path=/docs/document-footer-metadata
 * - https://components.publishing.service.gov.uk/component-guide/document_list
 */
export const DocumentFooterMetadata = (_a) => {
    var { from = undefined, partOf = undefined, other = undefined } = _a, props = __rest(_a, ["from", "partOf", "other"]);
    const fromData = (React.createElement(StyledContainer, null, from && (React.createElement("div", null,
        React.createElement("p", { style: { marginBottom: 0 } }, "From:"),
        React.createElement(UnorderedList, { listStyleType: "none" }, from &&
            from.map((child, i) => (
            /* eslint-disable react/no-array-index-key */
            React.createElement(StyledDefinition, { key: i }, child)
            /* eslint-enable react/no-array-index-key */
            )))))));
    const partOfData = (React.createElement(StyledContainer, null, partOf && (React.createElement("div", null,
        React.createElement("p", { style: { marginBottom: 0 } }, "Part of:"),
        React.createElement(UnorderedList, { listStyleType: "none" }, Array.isArray(partOf) &&
            React.Children.map(partOf, (child, i) => React.createElement(StyledDefinition, null, child)))))));
    const otherData = (React.createElement(StyledContainer, null, other &&
        other.map((item) => (React.createElement("div", { key: item.id },
            React.createElement("p", { style: { marginBottom: 0 } },
                item.title,
                ":"),
            React.createElement(UnorderedList, { listStyleType: "none" },
                React.createElement(StyledDefinition, null, item.content)))))));
    return (React.createElement(StyledContainer, Object.assign({}, props),
        fromData,
        partOfData,
        otherData));
};
DocumentFooterMetadata.defaultProps = {
    from: undefined,
    partOf: undefined,
    other: undefined,
};
DocumentFooterMetadata.displayName = 'DocumentFooterMetadata';
export default DocumentFooterMetadata;
