var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
// @ts-nocheck
import * as React from 'react';
import styled from 'styled-components';
import { TEXT_COLOR, ERROR_COLOR, FOCUS_COLOR } from '../../global/colors';
import { H2 } from '../Heading/presets';
import Paragraph from '../Paragraph';
import UnorderedList from '../UnorderedList';
import Link from '../Link';
import ListItem from '../ListItem';
import { NTA_LIGHT, FONT_SIZE, BORDER_WIDTH, BORDER_WIDTH_MOBILE, FOCUS_WIDTH, LINE_HEIGHT, SPACING, MEDIA_QUERIES, RESPONSIVE_4, } from '../../constants';
import { spacing } from '../../global';
const StyledErrorText = styled(Link)({
    fontFamily: NTA_LIGHT,
    WebkitFontSmoothing: 'antialiased',
    MozOsxFontSmoothing: 'grayscale',
    fontWeight: 700,
    marginBottom: SPACING.SCALE_1,
    textDecoration: 'underline',
    textDecorationSkipInk: 'none',
    textTransform: 'none',
    cursor: 'pointer',
    fontSize: FONT_SIZE.SIZE_16,
    lineHeight: LINE_HEIGHT.SIZE_16,
    ':visited': {
        color: `${ERROR_COLOR}`,
    },
    [MEDIA_QUERIES.LARGESCREEN]: {
        fontSize: FONT_SIZE.SIZE_19,
        lineHeight: LINE_HEIGHT.SIZE_19,
    },
    color: `${ERROR_COLOR}`,
    paddingTop: '4px',
    paddingBottom: '2px',
});
const StyledErrorSummary = styled('div')({
    color: TEXT_COLOR,
    padding: RESPONSIVE_4.mobile,
    border: `${BORDER_WIDTH_MOBILE} solid ${ERROR_COLOR}`,
    '&:focus': {
        outline: `${FOCUS_WIDTH} solid ${FOCUS_COLOR}`,
        outlineOffset: '0',
    },
    [MEDIA_QUERIES.LARGESCREEN]: {
        padding: RESPONSIVE_4.tablet,
        border: `${BORDER_WIDTH} solid ${ERROR_COLOR}`,
    },
}, spacing.withWhiteSpace({ marginBottom: 6 }));
/**
 * Use this component at the top of a page to summarise any errors a user has made.
 *
 * - https://govuk-react.github.io/govuk-react/?path=/docs/error-summary
 * - https://design-system.service.gov.uk/components/error-summary/
 */
export const ErrorSummary = (_a) => {
    var { onHandleErrorClick = undefined, heading = 'There is a problem', description = undefined, errors = [] } = _a, props = __rest(_a, ["onHandleErrorClick", "heading", "description", "errors"]);
    return (React.createElement(StyledErrorSummary, Object.assign({ tabIndex: -1 }, props),
        React.createElement(H2, { size: "MEDIUM" }, heading),
        description && React.createElement(Paragraph, { mb: 3 }, description),
        errors.length > 0 && (React.createElement(UnorderedList, { mb: 0, listStyleType: "none" }, errors.map((error, index) => (React.createElement(ListItem, { key: error.targetName },
            React.createElement(StyledErrorText, { tabIndex: index + 1, onClick: () => onHandleErrorClick === null || onHandleErrorClick === void 0 ? void 0 : onHandleErrorClick(error.targetName) }, error.text))))))));
};
ErrorSummary.defaultProps = {
    description: undefined,
    errors: [],
    heading: 'There is a problem',
    onHandleErrorClick: undefined,
};
ErrorSummary.displayName = 'ErrorSummary';
export default ErrorSummary;
