/**
 * ### References:
 *
 * - https://github.com/alphagov/govuk-frontend/blob/main/src/govuk/components/footer/template.njk
 * - https://github.com/alphagov/govuk-frontend/blob/main/src/govuk/components/footer/_footer.scss
 */
import * as React from 'react';
import type { CopyrightProps } from './atoms/copyright';
import WidthContainer from './atoms/width-container';
import Navigation from './atoms/navigation';
import Link from './atoms/link';
import MetaCustom from './atoms/meta-custom';
import MetaLinks from './molecules/meta-links';
import NavigationLinks from './molecules/navigation-links';
/**
 * The footer provides copyright, licensing and other information about your service and department.
 *
 * - https://govuk-react.github.io/govuk-react/?path=/docs/footer
 * - https://design-system.service.gov.uk/components/footer/
 *
 */
export declare const Footer: FooterType;
export interface FooterType extends React.FC<FooterProps> {
    Link: typeof Link;
    Navigation: typeof Navigation;
    MetaCustom: typeof MetaCustom;
    MetaLinks: typeof MetaLinks;
    NavigationLinks: typeof NavigationLinks;
    WidthContainer: typeof WidthContainer;
}
interface FooterProps {
    /**
     * Footer navigation links
     */
    children?: React.ReactNode;
    /**
     * Override the default footer container component.
     * `children`, `copyright` and `meta` will be placed inside this component.
     */
    container?: React.ElementType;
    /**
     * Copyright information
     */
    copyright?: CopyrightProps;
    /**
     * Meta text and links
     */
    meta?: React.ReactNode;
}
export default Footer;
//# sourceMappingURL=Footer.d.ts.map