var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
//@ts-nocheck
/**
 * ### References:
 *
 * - https://github.com/alphagov/govuk-frontend/blob/main/src/govuk/components/footer/template.njk
 * - https://github.com/alphagov/govuk-frontend/blob/main/src/govuk/components/footer/_footer.scss
 */
import * as React from 'react';
import styled from 'styled-components';
import { spacing, typography } from '../../global';
import { FOOTER_BACKGROUND, FOOTER_TEXT, FOOTER_BORDER_TOP } from '../../global/colors';
import WidthContainer from './atoms/width-container';
import Navigation from './atoms/navigation';
import Link from './atoms/link';
import SectionBreak from './atoms/section-break';
import MetaCustom from './atoms/meta-custom';
import MetaContainer from './molecules/meta-container';
import MetaLinks from './molecules/meta-links';
import NavigationLinks from './molecules/navigation-links';
const FooterContainer = styled('footer')({
    borderTop: `1px solid ${FOOTER_BORDER_TOP}`,
    background: `${FOOTER_BACKGROUND}`,
    color: `${FOOTER_TEXT}`,
}, typography.font({ size: 16 }), spacing.withWhiteSpace({
    padding: [
        { size: 7, direction: 'top' },
        { size: 5, direction: 'bottom' },
    ],
}));
/**
 * The footer provides copyright, licensing and other information about your service and department.
 *
 * - https://govuk-react.github.io/govuk-react/?path=/docs/footer
 * - https://design-system.service.gov.uk/components/footer/
 *
 */
export const Footer = (_a) => {
    var { children = undefined, container: Container = Footer.WidthContainer, copyright = undefined, meta = undefined } = _a, props = __rest(_a, ["children", "container", "copyright", "meta"]);
    return (React.createElement(FooterContainer, Object.assign({ role: "contentinfo" }, props),
        React.createElement(Container, null,
            children && (React.createElement(React.Fragment, null,
                children,
                React.createElement(SectionBreak, null))),
            React.createElement(MetaContainer, { copyright: copyright }, meta))));
};
Footer.displayName = 'Footer';
Footer.Link = Link;
Footer.Navigation = Navigation;
Footer.MetaCustom = MetaCustom;
Footer.MetaLinks = MetaLinks;
Footer.NavigationLinks = NavigationLinks;
Footer.WidthContainer = WidthContainer;
Footer.defaultProps = {
    children: undefined,
    container: Footer.WidthContainer,
    copyright: undefined,
    meta: undefined,
};
export default Footer;
