//@ts-nocheck
/**
 * ### References:
 *
 * - https://github.com/alphagov/govuk_frontend_toolkit/blob/master/stylesheets/_grid_layout.scss
 * - https://github.com/alphagov/govuk_elements/blob/master/assets/sass/elements/_layout.scss
 */
import styled from 'styled-components';
import { GUTTER_HALF, MEDIA_QUERIES } from '../../constants';
import { spacing } from '../../global';
const colValues = {
    columnOneQuarter: '25%',
    columnOneThird: '33.3333%',
    columnOneHalf: '50%',
    columnTwoThirds: '66.6667%',
    columnThreeQuarters: '75%',
    columnFull: '100%',
};
const widthFromProps = spacing.withWidth({ noDefault: true });
const desktopWidthFromProps = spacing.withWidth({
    mediaQuery: MEDIA_QUERIES.DESKTOP,
    noDefault: true,
});
function setGrowShrink(style) {
    const hasAutoWidth = [undefined, 'auto'].includes(style.width);
    // No explicit width means auto, so grow/shrink should be set
    return Object.assign(Object.assign({}, style), { flexGrow: hasAutoWidth ? 1 : 0, flexShrink: hasAutoWidth ? 1 : 0 });
}
/**
 * Grid Column.
 *
 * Should always be wrapped by `GridRow`. Will always render a column at full width if
 * the browser width is below the `TABLET` breakpoint.
 *
 * NB our grid is based on flex-box, which differs from govuk-frontend, which instead uses
 * floats, however it is otherwise similar to use.
 *
 * - https://govuk-react.github.io/govuk-react/?path=/docs/grid-col
 *
 */
export const GridCol = styled('div')({
    boxSizing: 'border-box',
    paddingRight: GUTTER_HALF,
    paddingLeft: GUTTER_HALF,
}, (props) => {
    // if setWidth is set, then columnOneQuarter etc props will be ignored
    let widthStyle = widthFromProps(props);
    if (!widthStyle) {
        let widthValue;
        Object.entries(props).forEach(([key, value]) => {
            if (colValues[key] && value === true) {
                if (process.env.NODE_ENV !== 'production') {
                    const newKey = key
                        .replace('column', '')
                        .replace(/^([A-Z][a-z]+)([A-Z])/, '$1-$2')
                        .toLocaleLowerCase();
                    // eslint-disable-next-line no-console
                    console.warn(`deprecated prop ${key} used in GridCol, please replace with setWidth="${newKey}"`);
                }
                widthValue = colValues[key];
            }
        });
        widthStyle = {
            [MEDIA_QUERIES.TABLET]: {
                width: widthValue,
            },
        };
    }
    widthStyle[MEDIA_QUERIES.TABLET] = setGrowShrink(widthStyle[MEDIA_QUERIES.TABLET]);
    const desktopWidthStyle = desktopWidthFromProps({
        setWidth: props.setDesktopWidth,
    });
    if (desktopWidthStyle) {
        desktopWidthStyle[MEDIA_QUERIES.DESKTOP] = setGrowShrink(desktopWidthStyle[MEDIA_QUERIES.DESKTOP]);
    }
    return Object.assign(Object.assign({}, widthStyle), desktopWidthStyle);
});
GridCol.defaultProps = {
    children: undefined,
    columnOneQuarter: false,
    columnOneThird: false,
    columnOneHalf: false,
    columnTwoThirds: false,
    columnThreeQuarters: false,
    columnFull: false,
    setWidth: undefined,
    setDesktopWidth: undefined,
};
GridCol.displayName = 'GridCol';
export default GridCol;
