//@ts-nocheck
/**
 * ### References:
 *
 * - https://github.com/alphagov/govuk_frontend_toolkit/blob/master/stylesheets/_typography.scss
 * - https://github.com/alphagov/govuk-frontend/blob/main/src/govuk/core/_typography.scss
 */
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
import styled from 'styled-components';
import * as React from 'react';
import { HEADING_SIZES, LEVEL_SIZE, LEVEL_TAG, MEDIA_QUERIES, TYPOGRAPHY_SCALE } from '../../constants';
import { spacing, typography } from '../../global';
// use `size` only with string for XLARGE, SMALL etc and number for px size
// so if `size` is a string, we find a numeric size based off `HEADING_SIZES`
// but if `size` is a number we just send through that number
const StyledHeading = styled('h1')(typography.textColor, ({ size }) => {
    const actualSize = Number.isNaN(Number(size)) ? HEADING_SIZES[size] : size;
    if (!actualSize) {
        throw Error(`Unknown size ${size} used for heading.`);
    }
    return Object.assign({}, typography.font({ size: actualSize, weight: 'bold' }));
}, {
    display: 'block',
    marginTop: 0,
}, ({ size }) => {
    const actualSize = Number.isNaN(Number(size)) ? HEADING_SIZES[size] : size;
    const scaleInfo = TYPOGRAPHY_SCALE[actualSize];
    return {
        marginBottom: scaleInfo.mobile.spacing,
        [MEDIA_QUERIES.TABLET]: {
            marginBottom: scaleInfo.tablet.spacing,
        },
    };
}, spacing.withWhiteSpace());
/**
 * Use heading tags, such as `<h1>`, `<h2>` and so on, to tag the headings on a page.
 *
 * - https://govuk-react.github.io/govuk-react/?path=/docs/heading
 * - https://design-system.service.gov.uk/styles/typography/#headings
 */
export const Heading = (_a) => {
    var { level = undefined, size = 'XLARGE' } = _a, props = __rest(_a, ["level", "size"]);
    if (level) {
        if (process.env.NODE_ENV !== 'production') {
            // eslint-disable-next-line no-console
            console.warn(`deprecated prop 'level' used in Heading, please replace with an "H${level}" component`);
        }
        if (LEVEL_TAG[level]) {
            return React.createElement(StyledHeading, Object.assign({ size: LEVEL_SIZE[level] }, props, { as: LEVEL_TAG[level] }));
        }
    }
    return React.createElement(StyledHeading, Object.assign({ size: size }, props));
};
Heading.displayName = 'Heading';
export default Heading;
