var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
import React, { useState, useEffect, useContext, useCallback } from 'react';
import { RootContainer, ContentsContainer, ContentsTitle, ContentsSectionList, ContentsSection, NavigatorContainer, NavigatorContent, NavigationBar, NavigationButton } from './styles';
import { ButtonArrow } from "../../icons/src";
import { WHITE, BLACK, GREY_2 } from "../../global/colors";
import { InPageNavigationContext, InPageNavigationProvider, SectionContext } from "./context";
const StatefulInPageNavigation = ({ contentsTitle, backButton, nextButton, finalButton, maxContentWidth = '800px', children, nextButtonHandler = () => true, finalButtonHandler }) => {
    const { currentSectionIndex, setCurrentSectionIndex, maxAllowedIndex, setMaxAllowedIndex, navigationData, isNextButtonEnabled } = useContext(InPageNavigationContext);
    const [titles, setTitles] = useState([]);
    const [components, setComponents] = useState([]);
    useEffect(() => {
        const handleChildren = (children, index = 0, prefix = '') => {
            if (children instanceof Array) {
                return children.map((child, index) => handleChildren(child, index, prefix)).flat();
            }
            else {
                let { title, children: grandchildren } = children.props;
                if (!title || !grandchildren)
                    return [];
                const marker = `${prefix}${index + 1}${prefix ? '' : '.'}`;
                const newTitle = `${marker} ${title}`;
                if (grandchildren instanceof Array) {
                    const subsections = grandchildren.filter(grandchild => 'title' in grandchild.props);
                    grandchildren = grandchildren.filter(grandchild => !('title' in grandchild.props));
                    return [
                        [newTitle, grandchildren],
                        ...handleChildren(subsections, index, `${marker}${prefix ? '.' : ''}`)
                    ];
                }
                return [[newTitle, grandchildren]];
            }
        };
        handleChildren(children).map(([title, component]) => {
            setTitles(prevTitles => [...prevTitles, title]);
            setComponents(prevComponents => [...prevComponents, component]);
        });
    }, []);
    const moveForward = () => {
        setCurrentSectionIndex(prevIndex => {
            const newIndex = prevIndex + 1;
            setMaxAllowedIndex(prevMaxIndex => prevMaxIndex < newIndex ? newIndex : prevMaxIndex);
            return newIndex;
        });
    };
    const onNextButtonClick = useCallback(() => {
        const canMoveForward = nextButtonHandler(navigationData);
        if (!canMoveForward)
            return;
        moveForward();
    }, [navigationData, nextButtonHandler]);
    const moveBack = () => setCurrentSectionIndex(prevIndex => prevIndex > 0 ? prevIndex - 1 : prevIndex);
    const onContentsSectionClick = (index) => {
        if (maxAllowedIndex < index)
            return;
        setCurrentSectionIndex(index);
    };
    const onFinalButtonClick = useCallback(() => finalButtonHandler(navigationData), [navigationData, finalButtonHandler]);
    const isNextButtonDisabled = !isNextButtonEnabled;
    return (React.createElement(RootContainer, null,
        React.createElement(ContentsContainer, null,
            React.createElement(ContentsTitle, null, contentsTitle),
            React.createElement(ContentsSectionList, null, titles.map((title, index) => (React.createElement(ContentsSection, { key: title, onClick: () => onContentsSectionClick(index), isSelected: currentSectionIndex === index, isDisabled: maxAllowedIndex < index }, title))))),
        React.createElement(NavigatorContainer, { maxWidth: maxContentWidth },
            components.map((component, index) => (React.createElement(NavigatorContent, { key: index, isHidden: currentSectionIndex !== index },
                React.createElement(ContentsTitle, null, titles[index]),
                React.createElement(SectionContext.Provider, { value: { index, title: titles[index] } }, component)))),
            React.createElement(NavigationBar, null,
                React.createElement(NavigationButton, { buttonColor: GREY_2, buttonTextColor: BLACK, leftSideIcon: true, icon: React.createElement(ButtonArrow, { fill: BLACK }), disabled: currentSectionIndex === 0, onClick: moveBack }, backButton),
                currentSectionIndex === components.length - 1 ? (React.createElement(NavigationButton, { disabled: isNextButtonDisabled, onClick: onFinalButtonClick }, finalButton)) : (React.createElement(NavigationButton, { icon: React.createElement(ButtonArrow, { fill: WHITE }), disabled: isNextButtonDisabled, onClick: onNextButtonClick }, nextButton))))));
};
const InPageNavigation = (_a) => {
    var { initialNavigationData, onNavigationDataChange } = _a, props = __rest(_a, ["initialNavigationData", "onNavigationDataChange"]);
    return (React.createElement(InPageNavigationProvider, { initialNavigationData: initialNavigationData || {}, onNavigationDataChange: onNavigationDataChange },
        React.createElement(StatefulInPageNavigation, Object.assign({}, props))));
};
InPageNavigation.displayName = 'InPageNavigation';
export default InPageNavigation;
InPageNavigation.Section = () => null;
InPageNavigation.Section.displayName = 'InPageNavigation.Section';
