/* InPageNavigation */
import React, { createContext, useContext, useState, useEffect } from 'react';
const InPageNavigationContext = createContext({});
const { Provider, Consumer: InPageNavigationConsumer } = InPageNavigationContext;
const InPageNavigationProvider = ({ initialNavigationData, onNavigationDataChange, children }) => {
    const [navigationData, setNavigationData] = useState(initialNavigationData);
    useEffect(() => onNavigationDataChange === null || onNavigationDataChange === void 0 ? void 0 : onNavigationDataChange(navigationData), [navigationData]);
    const [isNextButtonEnabled, setIsNextButtonEnabled] = useState(true);
    const [currentSectionIndex, setCurrentSectionIndex] = useState(0);
    const [maxAllowedIndex, setMaxAllowedIndex] = useState(0);
    return (React.createElement(Provider, { value: {
            navigationData, setNavigationData,
            isNextButtonEnabled, setIsNextButtonEnabled,
            currentSectionIndex, setCurrentSectionIndex,
            maxAllowedIndex, setMaxAllowedIndex
        } }, children));
};
const useInPageNavigation = () => {
    const { navigationData, setNavigationData, setIsNextButtonEnabled, currentSectionIndex } = useContext(InPageNavigationContext);
    const createNavigationDataChangeListener = (name, handlers) => {
        return (key) => {
            const handler = handlers[key];
            return (e) => setNavigationData((prevEvents) => {
                const listenerData = prevEvents[name];
                return Object.assign(Object.assign({}, prevEvents), { [name]: Object.assign(Object.assign({}, listenerData), { [key]: handler === null || handler === void 0 ? void 0 : handler(e, listenerData === null || listenerData === void 0 ? void 0 : listenerData[key]) }) });
            });
        };
    };
    const { index: sectionIndex } = useContext(SectionContext);
    const enableNextButton = () => {
        if (sectionIndex !== currentSectionIndex)
            return;
        setIsNextButtonEnabled(true);
    };
    const disableNextButton = () => {
        if (sectionIndex !== currentSectionIndex)
            return;
        setIsNextButtonEnabled(false);
    };
    return {
        navigationData,
        createNavigationDataChangeListener,
        enableNextButton,
        disableNextButton
    };
};
export { InPageNavigationContext, InPageNavigationProvider, InPageNavigationConsumer, useInPageNavigation };
const SectionContext = createContext({});
const useSection = () => useContext(SectionContext);
export { SectionContext, useSection };
