import { DatePickerProps } from '@mui/x-date-pickers';
import { TextFieldProps } from '@mui/material';
import React from 'react';
interface IDateInput extends Omit<React.HTMLProps<HTMLInputElement>, 'value'> {
    value: Date | null;
}
declare type IInput = Partial<IDateInput> & Partial<TextFieldProps>;
interface IOwnProps {
    meta?: {
        error?: string | Array<string>;
        touched?: boolean;
    };
    label?: string;
    onChange: (arg0: Date | null) => void;
    input: IInput;
    muiPickerProps?: Partial<DatePickerProps<Date, Date>>;
    locale?: Locale;
}
/**
 * Wrapper for Mui DatePicker component. Documentation:
 * https://mui.com/x/react-date-pickers/date-picker/
 *
 * API for DateTimePicker component:
 * https://mui.com/x/api/date-pickers/date-picker/
 *
 * - param `muiPickerProps` - props for Mui Picker, see API for avilible props
 *
 * - param `input` - props for HTML Input element, Mui TextField props are also forwarded through this prop
 * 	- `value` is required
 * 	- see https://mui.com/material-ui/api/text-field/ for possible TextField props
 *
 * - param `locale`
 * 	- custom dayjs locale prop, default is `sk`
 * 	- additional ones import like `import { enGB } from 'date-fns/locale';`
 *
 * - param `meta` - Object for error handling
 *
 * - param `label` - label for the input field
 *
 * - param `onChange`
 * 	- custom onChange function for the DateTimePicker component
 * 	- basic example usage `onChange={(newValue) => setValue(newValue)}`
 * 	- newValue: Object with date and time properties, entire js Date object under `.d` property
 * 	- if date entered into picker is incorrect (for example 32.02.2022), newValue will be `'Invalid Date'`
 * 	- initial value is `null`
 *
 */
export declare const MuiDatePicker: React.VFC<IOwnProps>;
export default MuiDatePicker;
//# sourceMappingURL=MuiDatePicker.d.ts.map