import { createTheme, ThemeProvider } from '@mui/material/styles';
import { LocalizationProvider, DatePicker, } from '@mui/x-date-pickers';
import React from 'react';
import MuiTextField from './MuiTextField/MuiTextField';
import { YELLOW } from '../../global/colors';
import { sk } from 'date-fns/locale';
import { AdapterDateFns } from '@mui/x-date-pickers/AdapterDateFns';
const theme = createTheme({
    palette: {
        primary: { main: YELLOW, light: YELLOW, dark: YELLOW },
    },
    shape: {
        borderRadius: 0,
    },
});
/**
 * Wrapper for Mui DatePicker component. Documentation:
 * https://mui.com/x/react-date-pickers/date-picker/
 *
 * API for DateTimePicker component:
 * https://mui.com/x/api/date-pickers/date-picker/
 *
 * - param `muiPickerProps` - props for Mui Picker, see API for avilible props
 *
 * - param `input` - props for HTML Input element, Mui TextField props are also forwarded through this prop
 * 	- `value` is required
 * 	- see https://mui.com/material-ui/api/text-field/ for possible TextField props
 *
 * - param `locale`
 * 	- custom dayjs locale prop, default is `sk`
 * 	- additional ones import like `import { enGB } from 'date-fns/locale';`
 *
 * - param `meta` - Object for error handling
 *
 * - param `label` - label for the input field
 *
 * - param `onChange`
 * 	- custom onChange function for the DateTimePicker component
 * 	- basic example usage `onChange={(newValue) => setValue(newValue)}`
 * 	- newValue: Object with date and time properties, entire js Date object under `.d` property
 * 	- if date entered into picker is incorrect (for example 32.02.2022), newValue will be `'Invalid Date'`
 * 	- initial value is `null`
 *
 */
export const MuiDatePicker = ({ meta, label, onChange, input, locale, muiPickerProps, }) => {
    return (React.createElement(ThemeProvider, { theme: theme },
        React.createElement(LocalizationProvider, { dateAdapter: AdapterDateFns, adapterLocale: locale || sk },
            React.createElement(DatePicker, Object.assign({ renderInput: (params) => (React.createElement(MuiTextField, { input: Object.assign(Object.assign({}, input), params), meta: meta, label: label })), onChange: (e) => onChange(e), inputFormat: (muiPickerProps === null || muiPickerProps === void 0 ? void 0 : muiPickerProps.inputFormat) || 'dd/MM/yyyy' }, Object.assign(Object.assign({}, muiPickerProps), { value: input.value || null }))))));
};
export default MuiDatePicker;
