var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
//@ts-nocheck
/**
 * ### References:
 *
 * - https://github.com/alphagov/govuk-frontend/tree/main/src/govuk/components/panel
 */
import * as React from 'react';
import styled from 'styled-components';
import { TURQUOISE, WHITE } from '../../global/colors';
import { spacing, typography } from '../../global';
import { BORDER_WIDTH, MEDIA_QUERIES, SPACING_POINTS } from '../../constants';
import { stripUnit } from 'polished';
const RAW_BORDER_WIDTH = Number(stripUnit(BORDER_WIDTH));
const StyledPanel = styled('div')(typography.font({ size: 19 }), {
    boxSizing: 'border-box',
    marginBottom: SPACING_POINTS[3],
    // NB govuk-frontend has this element styled tablet-first
    padding: SPACING_POINTS[6] - RAW_BORDER_WIDTH,
    border: `${BORDER_WIDTH} solid transparent`,
    textAlign: 'center',
    // NB govuk-frontend has this media query as an `until tablet` (thus for mobile)
    [MEDIA_QUERIES.TABLET]: {
        padding: SPACING_POINTS[7] - RAW_BORDER_WIDTH,
    },
    color: WHITE,
    background: TURQUOISE,
}, spacing.withWhiteSpace());
// NB govuk-frontend allows for the headingLevel to change, but defaults to h1
// we're not supporting headingLevel at this time
const StyledTitle = styled('h1')({
    marginTop: 0,
    marginBottom: SPACING_POINTS[6],
    ':last-child': {
        marginBottom: 0,
    },
}, typography.font({ size: 48, weight: 'bold' }));
const StyledBody = styled('div')(typography.font({ size: 36 }));
/**
 * The panel component is a visible container used on confirmation or results pages to highlight important content.
 *
 * - https://govuk-react.github.io/govuk-react/?path=/docs/panel
 * - https://design-system.service.gov.uk/components/panel/
 *
 */
export const Panel = (_a) => {
    var { title, children } = _a, props = __rest(_a, ["title", "children"]);
    return (React.createElement(StyledPanel, Object.assign({}, props),
        React.createElement(StyledTitle, null, title),
        children && React.createElement(StyledBody, null, children)));
};
Panel.defaultProps = {
    children: undefined,
};
Panel.displayName = 'Panel';
export default Panel;
