var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
import * as React from 'react';
import styled from 'styled-components';
import { FOCUS_COLOR } from '../../global/colors';
import { spacing, typography } from '../../global';
import HintText from '../HintText';
import { BORDER_WIDTH_FORM_ELEMENT, FOCUS_WIDTH, FOCUS_WIDTH_RAW, MEDIA_QUERIES, SPACING_POINTS, } from '../../constants';
const radioSize = SPACING_POINTS[7];
const labelPaddingLeftRight = SPACING_POINTS[3];
// When the default focus width is used on a curved edge it looks visually smaller.
// So for the circular radios we bump the default to make it look visually consistent.
const RADIOS_FOCUS_WIDTH = `${FOCUS_WIDTH_RAW + 1}px`;
const Label = styled('label')(typography.font({ size: 19 }), {
    display: 'block',
    position: 'relative',
    minHeight: radioSize,
    padding: `0 0 0 ${radioSize}px`,
    clear: 'left',
}, ({ inline }) => inline && {
    [MEDIA_QUERIES.LARGESCREEN]: {
        float: 'left',
        clear: 'none',
        marginRight: SPACING_POINTS[4],
    },
}, spacing.withWhiteSpace({ marginBottom: 2 }));
const Input = styled('input')({
    position: 'absolute',
    zIndex: 1,
    top: 0,
    left: 0,
    width: radioSize,
    height: radioSize,
    cursor: 'pointer',
    opacity: 0,
    ':checked + span::after': {
        opacity: 1,
    },
    ':focus + span::before': {
        outline: `${FOCUS_WIDTH} solid transparent`,
        outlineOffset: FOCUS_WIDTH,
        boxShadow: `0 0 0 ${RADIOS_FOCUS_WIDTH} ${FOCUS_COLOR}`,
    },
}, ({ disabled }) => ({
    cursor: disabled ? 'auto' : 'pointer',
    ' + span': {
        opacity: disabled ? '.5' : '1',
        pointerEvents: disabled ? 'none' : 'auto',
    },
}));
const LabelText = styled('span')({
    display: 'inline-block',
    marginBottom: 0,
    padding: `8px ${labelPaddingLeftRight}px ${SPACING_POINTS[1]}px`,
    cursor: 'pointer',
    MsTouchAction: 'manipulation',
    touchAction: 'manipulation',
    ':before': {
        content: "''",
        boxSizing: 'border-box',
        position: 'absolute',
        top: 0,
        left: 0,
        width: radioSize,
        height: radioSize,
        border: `${BORDER_WIDTH_FORM_ELEMENT} solid black`,
        borderRadius: '50%',
        background: 'transparent',
    },
    ':after': {
        content: "''",
        position: 'absolute',
        top: SPACING_POINTS[2],
        left: SPACING_POINTS[2],
        width: 0,
        height: 0,
        border: `${SPACING_POINTS[2]}px solid`,
        borderRadius: '50%',
        opacity: 0,
    },
});
const StyledRadioHint = styled(HintText)({
    display: 'block',
    paddingLeft: labelPaddingLeftRight,
    paddingRight: labelPaddingLeftRight,
});
export const Radio = React.forwardRef((_a, ref) => {
    var { inline, children, className, hint } = _a, input = __rest(_a, ["inline", "children", "className", "hint"]);
    return (React.createElement(Label, { inline: inline, className: className },
        React.createElement(Input, Object.assign({ type: "radio", ref: ref }, input)),
        React.createElement(LabelText, null, children),
        hint && React.createElement(StyledRadioHint, null, hint)));
});
Radio.defaultProps = {
    hint: undefined,
    inline: false,
    className: undefined,
};
Radio.displayName = 'Radio';
export default Radio;
