import React, { useEffect, useState } from 'react';
import { StyledFilterContainer, StyledTableHeader, StyledFilterToggleButton, StyledFilterInputsContainer, StyledFilterCancelButton, StyledTableFilterCategory, StyleParameterRemove } from './styles';
import H1 from '../Heading';
import Button from '../Button';
import GridRow from '../GridRow';
import GridCol from '../GridCol';
export const FilteredItem = ({ itemName, onItemCancel }) => {
    return (React.createElement(StyleParameterRemove, { onClick: () => onItemCancel() },
        React.createElement("button", null,
            itemName,
            React.createElement("span", null, "X"))));
};
export const FilterCategory = ({ children, categoryName, initialOpened = false, }) => {
    const [showCategory, setShowCategory] = useState(initialOpened);
    return (React.createElement(StyledTableFilterCategory, null,
        React.createElement(StyledTableHeader, null,
            React.createElement(H1, { size: 'SMALL' }, categoryName),
            React.createElement(StyledFilterToggleButton, { onClick: () => setShowCategory(!showCategory) }, !showCategory ? 'Rozbaliť sekciu filtra' : 'Zbaliť sekciu filtra')),
        React.createElement("div", { className: showCategory ? 'filter-content' : 'filter-content-hidden' }, children)));
};
const TableFilter = ({ filteredCount, acttiveFilteredCount, filterTitle, children, filteredItems, initialOpened = false, onFilterConfirm, onFilterCancel }) => {
    const [showFilter, setShowFilter] = useState(initialOpened);
    const [showActiveFilter, setShowActiveFilter] = useState(false);
    const [shrinkActiveFilter, setShrinkActiveFilter] = useState(false);
    useEffect(() => {
        (acttiveFilteredCount && acttiveFilteredCount > 0) ? setShowActiveFilter(true) : setShowActiveFilter(false);
    }, [acttiveFilteredCount]);
    return (React.createElement(React.Fragment, null,
        React.createElement(StyledFilterContainer, null,
            React.createElement(StyledTableHeader, null,
                React.createElement(H1, { size: 'MEDIUM' }, filterTitle),
                React.createElement(StyledFilterToggleButton, { onClick: () => setShowFilter(!showFilter) }, !showFilter ? 'Rozbaliť obsah filtra' : 'Zbaliť obsah filtra')),
            React.createElement("div", { className: showFilter ? 'filter-content' : 'filter-content-hidden' },
                React.createElement(StyledFilterInputsContainer, null, children),
                React.createElement(Button, { disabled: filteredCount < 1, onClick: () => onFilterConfirm() },
                    'Filtrovať',
                    " (",
                    React.createElement("span", null, filteredCount),
                    ")"))),
        showActiveFilter &&
            React.createElement(StyledFilterContainer, null,
                React.createElement(StyledTableHeader, null,
                    React.createElement(GridRow, null,
                        React.createElement(GridCol, { setWidth: "one-half" },
                            React.createElement(H1, { size: 'SMALL' }, "Akt\u00EDvny filter")),
                        React.createElement(GridCol, { setWidth: "one-half" },
                            React.createElement(StyledFilterToggleButton, { onClick: () => setShrinkActiveFilter(!shrinkActiveFilter) }, shrinkActiveFilter ? 'Rozbaliť aktívny filter' : 'Zbaliť aktívny filter')))),
                React.createElement("div", { className: !shrinkActiveFilter ? 'filter-content' : 'filter-content-hidden' },
                    filteredItems,
                    React.createElement(StyledFilterCancelButton, { disabled: acttiveFilteredCount < 1, onClick: () => onFilterCancel() },
                        'Zrušiť všetko',
                        " ",
                        `(${acttiveFilteredCount})`,
                        React.createElement(StyleParameterRemove, null, "X"))))));
};
TableFilter.FilteredItem = FilteredItem;
TableFilter.Category = FilterCategory;
export default TableFilter;
