import { GREY_2, WHITE } from '../../global/colors';
import styled, { css } from 'styled-components';
import { FONT_SIZE } from '../../constants';
export const StyledTableCell = styled.div `
  display: table-cell;
  border-bottom: 1px solid ${GREY_2};
  padding: 9.5px 10px;
  height: 46.6px;

  ${({ disableCopy }) => disableCopy &&
    css `
      -webkit-user-select: none;
      -khtml-user-select: none;
      -moz-user-select: none;
      -ms-user-select: none;
      user-select: none;
    `}


  span {
    font-size: ${FONT_SIZE.SIZE_16};
    font-weight: 400;
  }

  & > span,
  & > div > span:last-child {
    white-space: nowrap;
    text-overflow: ellipsis;
    display: block;
    -webkit-line-clamp: 1;
    -webkit-box-orient: vertical;
    overflow: hidden;
  }

  & > div {
    display: flex;
    align-items: baseline;

    & > span:last-child {
      width: 80%;
    }

    & > span:first-child {
      margin-right: 10px !important;
      top: 3px;
    }
  }
`;
export const StyledTableHeadCell = styled.div `
  display: table-cell;
  border-bottom: 1px solid ${GREY_2};
  padding: 10px 10px;
  height: 46.6px;

  & > div {
    display: flex;

    & > div {
      display: flex;
      flex-direction: column;
      justify-content: center;
      margin-left: 10px;
    }

    & > span {
      font-weight: 700;
      font-size: 19px;
      white-space: nowrap;
    }

    & > div > svg:first-child {
      transform: rotate(180deg);
      margin-bottom: 0.5px !important;
    }

    & > div > svg:last-child {
      margin-top: 0.5px !important;
    }
  }

  ${({ sortDirection }) => sortDirection === 'ASC' &&
    css `
      & > div > div > svg:last-child {
        visibility: hidden !important;
      }
    `}

  ${({ sortDirection }) => sortDirection === 'DESC' &&
    css `
      & > div > div > svg:first-child {
        visibility: hidden !important;
      }
    `}
`;
export const StyledTableBody = styled.div `
  display: table-row-group;
  position: relative;

  img {
    cursor: pointer;
  }
`;
export const StyledTableHead = styled.div `
  display: table-row-group;
  position: sticky;
  top: 0;
  z-index: 10;

  & > div {
    cursor: pointer;
  }
`;
export const StyledTableRow = styled.div `
  display: table-row;

  & > div {
    ${({ disableCopy }) => disableCopy &&
    css `
      -webkit-user-select: none;
      -khtml-user-select: none;
      -moz-user-select: none;
      -ms-user-select: none;
      user-select: none;
    `}
  }

  & > span {
    font-weight: 400;
  }

  :hover:not(${StyledTableHead} > div):not([class*='no-data']) {
    background-color: rgba(255, 223, 15, 0.25);
  }

  ${({ isSelect }) => isSelect &&
    css `
      background-color: rgba(255, 223, 15, 0.5) !important;
    `}
`;
export const StyledTableSorting = styled.div `
  background-color: ${({ colorTableBg }) => colorTableBg || 'transparent'};
  margin-bottom: 30px;
  overflow: auto;
  width: 100%;

  * {
    box-sizing: border-box;
  }

  & > h3 {
    padding: 10px;
    margin-bottom: 0;
  }

  h3 {
    white-space: nowrap;
  }

  span {
    padding: 0;
  }

  & > div {
    ${({ maxRows }) => maxRows &&
    css `
        max-height: ${`${46.6 * maxRows + 46.6}px`};
      `}
  }

  ${StyledTableHead} {
    background-color: ${({ colorTableBg }) => colorTableBg || WHITE};
  }

  ${StyledTableCell} {
    max-width: calc(100vw / ${({ columnCount }) => columnCount || 1} - 90px);
  }

  .no-data {
    height: 46.6px;
    & > span {
      position: absolute;
      font-size: 16px;
      padding: 12px 10px 10px 10px;
      text-align: center;
      height: 46.6px;
      width: 100%;
      border-bottom: 1px solid ${GREY_2};
    }
  }
`;
export const StyledTableContainer = styled.div `
  display: table;
  width: 100%;
`;
