import styled, { css } from 'styled-components';
import UnorderedList from '../UnorderedList';
import ListItem from '../ListItem';
import { FONT_SIZE, FONT_WEIGHTS, MEDIA_QUERIES } from '../../constants';
import { GREY_2, GREY_3, BLACK, WHITE, YELLOW } from '../../global/colors';
export const StyledUnorderedList = styled(UnorderedList) `
  margin-bottom: 20px;

  ${MEDIA_QUERIES.TABLET} {
    margin-bottom: 0;
    border-bottom: 1px solid ${GREY_2};
  }

  :after {
    content: '';
    display: block;
    clear: both;
  }

  li {
    font-weight: ${FONT_WEIGHTS.regular};
    font-size: ${FONT_SIZE.SIZE_16};
    line-height: 1.25;
    margin-left: 25px;

    ${MEDIA_QUERIES.TABLET} {
      font-size: ${FONT_SIZE.SIZE_19};
      line-height: 1.31579;
      position: relative;
      margin-right: 5px;
      margin-bottom: 0px;
      margin-left: 0;
      padding: 10px 20px;
      float: left;
      background-color: ${GREY_3};
      text-align: center;
    }
  }
`;
export const StyledSection = styled.section `
  margin-bottom: 30px;

  ${MEDIA_QUERIES.TABLET} {
    margin-bottom: 0;
    padding: 30px 20px;
    border: 1px solid ${GREY_2};
    border-top: 0;
  }
`;
export const StyledTabsWrapper = styled.div `
  margin-top: 5px;
  margin-bottom: 20px;

  ${StyledSection} {
    display: block;
  }

  ${MEDIA_QUERIES.TABLET} {
    margin-bottom: 30px;

    & > h6 {
      display: none;
    }

    ${StyledSection} {
      display: none;
    }

    ${StyledSection}:nth-of-type(${({ currentActive }) => currentActive}) {
      display: block;
    }
  }

  a {
    color: ${BLACK} !important;
    font-size: ${FONT_SIZE.SIZE_16};
    display: inline-block;
    width: max-content;

    :hover {
      color: ${BLACK};
      text-decoration: underline;
    }

    :focus {
      color: ${BLACK};
      background-color: ${YELLOW};
      box-shadow: 0 -2px ${YELLOW}, 0 4px ${BLACK};
      text-decoration: none;
      outline: 3px solid transparent;
    }

    :after {
      content: none;
    }
  }

  & > ul a {
    ${MEDIA_QUERIES.TABLET} {
      font-size: ${FONT_SIZE.SIZE_19};

      :after {
        content: '';
        position: absolute;
        top: 0;
        right: 0;
        bottom: 0;
        left: 0;
      }
    }
  }
`;
export const StyledListItem = styled(ListItem) `
  font-weight: ${FONT_WEIGHTS.regular};
  font-size: ${FONT_SIZE.SIZE_16};
  line-height: 1.25;
  margin-left: 25px;
  width: fit-content;

  :before {
    content: '\\2014 ';
    color: ${BLACK};
    margin-left: -25px;
    padding-right: 5px;
  }

  ${MEDIA_QUERIES.TABLET} {
    font-size: ${FONT_SIZE.SIZE_19};
    line-height: 1.31579;
    position: relative;
    margin-right: 5px;
    margin-bottom: 0px;
    margin-left: 0;
    padding: 10px 20px;
    float: left;
    background-color: ${GREY_2};
    text-align: center;

    :before {
      content: unset;
    }

    ${({ active }) => active &&
    css `
        margin-top: -5px !important;
        margin-bottom: -1px !important;
        padding-top: 14px !important;
        padding-right: 19px !important;
        padding-bottom: 16px !important;
        padding-left: 19px !important;
        border: 1px solid ${GREY_2} !important;
        border-bottom: 0 !important;
        background-color: ${WHITE} !important;

        a {
          text-decoration: none;
        }
      `}
  }
`;
