import styled from 'styled-components';
import visuallyHidden from '../../global/visualy-hiden';
/**
 * Hide an element visually, but have it available for screen readers.
 *
 * - https://govuk-react.github.io/govuk-react/?path=/docs/visually-hidden
 */
export const VisuallyHidden = styled('span')
    .withConfig({
    shouldForwardProp: (prop) => !['important', 'focusable'].includes(prop),
})
    .attrs(({ focusable, tabIndex }) => 
// if we're focusable but don't have a `tabIndex` set, add one
focusable && tabIndex === undefined ? { tabIndex: '0' } : undefined)(({ focusable, important }) => visuallyHidden({ focusable, important }));
VisuallyHidden.defaultProps = {
    focusable: false,
    important: true,
};
VisuallyHidden.displayName = 'VisuallyHidden';
export default VisuallyHidden;
