import React, { Component } from 'react';
import Paragraph from '../Paragraph';
import Button from '../Button';
import { VisuallyHidden } from './VisuallyHidden ';
export default {
    title: 'Utility/Visually hidden',
    id: 'visually-hidden',
    component: VisuallyHidden,
};
export const Default = (args) => (React.createElement(React.Fragment, null,
    React.createElement(Paragraph, null, "Following this paragraph is some hidden content. If `focusable` is enabled then you should be able to tab to it."),
    React.createElement(VisuallyHidden, Object.assign({}, args), "Some hidden content")));
Default.args = {
    focusable: true,
};
class Focusable extends Component {
    constructor(props) {
        super(props);
        // create a ref to store the focusable DOM element
        this.focusableRef = React.createRef();
    }
    componentDidMount() {
        var _a;
        (_a = this.focusableRef.current) === null || _a === void 0 ? void 0 : _a.focus();
    }
    render() {
        return React.createElement(VisuallyHidden, Object.assign({ ref: this.focusableRef, focusable: true }, this.props));
    }
}
export const FocussedFocusable = () => React.createElement(Focusable, null, "Focussed focusable VisuallyHidden element");
FocussedFocusable.parameters = {
    docs: {
        storyDescription: 'This story focusses the VisuallHideen component when it mounts. This is for visual regression testing.',
    },
};
export const FocussedFocusableAsAButton = () => (React.createElement(Focusable, { as: Button }, "VisuallyHidden as Button (focusable)"));
FocussedFocusableAsAButton.parameters = {
    docs: {
        storyDescription: 'This story focusses the VisuallHideen component when it mounts. This is for visual regression testing.',
    },
};
