// @ts-nocheck
import { FONT_STACK, FONT_STACK_PRINT, FONT_STACK_TABULAR, FONT_WEIGHTS, MEDIA_QUERIES, MEDIA_QUERY_PRINT, TYPOGRAPHY_SCALE, } from '../constants';
import { BLACK } from './colors';
export const textColor = {
    color: BLACK,
    [MEDIA_QUERIES.PRINT]: {
        color: '#000',
    },
};
export function common(fontFamily = FONT_STACK) {
    return {
        fontFamily,
        WebkitFontSmoothing: 'antialiased',
        MozOsxFontSmoothing: 'grayscale',
        [MEDIA_QUERY_PRINT]: {
            fontFamily: FONT_STACK_PRINT,
        },
    };
}
function getSizeStyle(scale, lineHeight = scale.lineHeight) {
    return {
        fontSize: `${scale.fontSize}px`,
        lineHeight,
    };
}
export function responsive(size, overrideLineHeight) {
    const scale = TYPOGRAPHY_SCALE[size];
    if (!scale) {
        throw Error(`Unknown font size ${size} - expected a point from the typography scale.`);
    }
    return Object.assign(Object.assign({}, getSizeStyle(scale.mobile, overrideLineHeight)), { [MEDIA_QUERIES.TABLET]: getSizeStyle(scale.tablet, overrideLineHeight), [MEDIA_QUERIES.PRINT]: getSizeStyle(scale.print, overrideLineHeight) });
}
export function font({ size, weight = 'regular', tabular = false, lineHeight } = {}) {
    return Object.assign(Object.assign(Object.assign({}, common(tabular ? FONT_STACK_TABULAR : undefined)), (FONT_WEIGHTS[weight] ? { fontWeight: FONT_WEIGHTS[weight] } : undefined)), (size ? responsive(size, lineHeight) : undefined));
}
